@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_POINTPARAMETER_H_
-#define _GMIC_QT_POINTPARAMETER_H_
+#ifndef GMIC_QT_POINTPARAMETER_H
+#define GMIC_QT_POINTPARAMETER_H
 
 #include <QColor>
 #include <QColorDialog>
@@ -94,4 +94,4 @@ private:
   static unsigned long _randomSeed;
 };
 
-#endif // _GMIC_QT_POINTPARAMETER_H_
+#endif // GMIC_QT_POINTPARAMETER_H
