@@ -236,9 +236,22 @@ int main(int argc, char **argv) {
         CImg<char>(argv[l],(unsigned int)std::strlen(argv[l])).move_to(items);
         CImg<char>::string("\"").move_to(items);
       } else CImg<char>::string(argv[l]).move_to(items);
-      if (l<argc - 1) items.back().back()=' ';
+      items.back().back()=' ';
     }
-    gmic_instance.verbosity = 1;
+
+    // Determine special mode for running .gmic files as scripts : 'gmic commands.gmic [arguments]'.
+    if ((argc==2 || argc==3) && !std::strcmp(cimg::split_filename(argv[1]),"gmic")) {
+      std::FILE *gmic_file = std::fopen(argv[1],"rb");
+      if (gmic_file) {
+        gmic().add_commands(gmic_file,argv[1],0,0,&gmic_instance.allow_entrypoint);
+        std::fclose(gmic_file);
+      }
+    }
+
+    // Determine initial verbosity.
+    const char *const s_verbosity = std::getenv("GMIC_VERBOSITY");
+    if (!s_verbosity || std::sscanf(s_verbosity,"%d%c",&gmic_instance.verbosity,&sep)!=1)
+      gmic_instance.verbosity = gmic_instance.allow_entrypoint?0:1;
   }
 
   // Insert startup command.
@@ -260,7 +273,8 @@ int main(int argc, char **argv) {
     items.insert(CImg<char>::string(tmpstr.data(),false),is_first_item_verbose?2:0);
   }
 
-  const CImg<char> commands_line(items>'x');
+  CImg<char> commands_line(items>'x');
+  commands_line.back() = 0;
   items.assign();
 
   // Launch G'MIC interpreter.
